==> epassauth-0.0.8.5-sources.jar: com/bambooclod/eaccount3/bean/DoAuthResponse.java <==
package com.bambooclod.eaccount3.bean;

/**
 * Comment: 统一认证返回实体
 *
 * @author Vangelis.Wang in BambooCloud
 * @date 2019-06-05
 * Email:wangpei@bamboocloud.cn
 */
public class DoAuthResponse {


    /**
     * epsessionId : epsession:admin:20190605155939200:7216
     * authConsumption : false
     * <p>
     * jwt : eyJhbGciOiJIUzI1NiJ9.eyJlcHRva2VuIjoidG9rZW46MTU1OTcyMTU3OTI2MSIsImFwcGlkIjo
     * iZXBhc3NfYXBwIiwic3VidG9rZW4iOiIiLCJ1c2VyaWQiOiJhZG1pbiIsImlhdCI6IjIwMTktMDYtMDUgMTUu
     * NTkuMzkiLCJ1cGR0IjoiMjAxOS0wNi0wNSAxNS41OS4zOSJ9.nz4WCIf8Zq-J4SEBKM4NFQVC3XTZ_u01e0hETwkopO0
     * <p>
     * optkey : Y2GGCGHBMWH67Q45
     * lastauthResult : true
     * authList : pwd,sms
     * authedList : pwd,sms
     * nextAuthType : none
     * addtionalInfo : {"voiceModelId":"1","otpKey":"Y2GGCGHBMWH67Q45","faceModelId":"1"}
     */

    private String epsessionId;
    private boolean authConsumption;
    private String jwt;
    private String optkey;
    private boolean lastauthResult;
    private String authList;
    private String authedList;
    private String nextAuthType;
    private AddtionalInfoBean addtionalInfo;
    private String devBindExpectAuthType;

    public String getEpsessionId() {
        return epsessionId;
    }

    public void setEpsessionId(String epsessionId) {
        this.epsessionId = epsessionId;
    }

    public boolean isAuthConsumption() {
        return authConsumption;
    }

    public void setAuthConsumption(boolean authConsumption) {
        this.authConsumption = authConsumption;
    }

    public String getDevBindExpectAuthType() {
        return devBindExpectAuthType;
    }

    public void setDevBindExpectAuthType(String devBindExpectAuthType) {
        this.devBindExpectAuthType = devBindExpectAuthType;
    }

    public String getJwt() {
        return jwt;
    }

    public void setJwt(String jwt) {
        this.jwt = jwt;
    }

    public String getOptkey() {
        return optkey;
    }

    public void setOptkey(String optkey) {
        this.optkey = optkey;
    }

    public boolean isLastauthResult() {
        return lastauthResult;
    }

    public void setLastauthResult(boolean lastauthResult) {
        this.lastauthResult = lastauthResult;
    }

    public String getAuthList() {
        return authList;
    }

    public void setAuthList(String authList) {
        this.authList = authList;
    }

    public String getAuthedList() {
        return authedList;
    }

    public void setAuthedList(String authedList) {
        this.authedList = authedList;
    }

    public String getNextAuthType() {
        return nextAuthType;
    }

    public void setNextAuthType(String nextAuthType) {
        this.nextAuthType = nextAuthType;
    }

    public AddtionalInfoBean getAddtionalInfo() {
        return addtionalInfo;
    }

    public void setAddtionalInfo(AddtionalInfoBean addtionalInfo) {
        this.addtionalInfo = addtionalInfo;
    }

    public static class AddtionalInfoBean {
        /**
         * voiceModelId : 1
         * otpKey : Y2GGCGHBMWH67Q45
         * faceModelId : 1
         */

        private String voiceModelId;
        private String otpKey;
        private String faceModelId;

        public String getVoiceModelId() {
            return voiceModelId;
        }

        public void setVoiceModelId(String voiceModelId) {
            this.voiceModelId = voiceModelId;
        }

        public String getOtpKey() {
            return otpKey;
        }

        public void setOtpKey(String otpKey) {
            this.otpKey = otpKey;
        }

        public String getFaceModelId() {
            return faceModelId;
        }

        public void setFaceModelId(String faceModelId) {
            this.faceModelId = faceModelId;
        }
    }
}

==> epassauth-0.1.0.8-sources.jar: com/bambooclod/eaccount3/bean/DoAuthResponse.java <==
package com.bambooclod.eaccount3.bean;

/**
 * Comment: 统一认证返回实体
 *
 * @author Vangelis.Wang in BambooCloud
 * @date 2019-06-05
 * Email:wangpei@bamboocloud.cn
 */
public class DoAuthResponse {


    /**
     * epsessionId : epsession:admin:20190605155939200:7216
     * authConsumption : false
     * <p>
     * jwt : eyJhbGciOiJIUzI1NiJ9.eyJlcHRva2VuIjoidG9rZW46MTU1OTcyMTU3OTI2MSIsImFwcGlkIjo
     * iZXBhc3NfYXBwIiwic3VidG9rZW4iOiIiLCJ1c2VyaWQiOiJhZG1pbiIsImlhdCI6IjIwMTktMDYtMDUgMTUu
     * NTkuMzkiLCJ1cGR0IjoiMjAxOS0wNi0wNSAxNS41OS4zOSJ9.nz4WCIf8Zq-J4SEBKM4NFQVC3XTZ_u01e0hETwkopO0
     * <p>
     * optkey : Y2GGCGHBMWH67Q45
     * lastauthResult : true
     * authList : pwd,sms
     * authedList : pwd,sms
     * nextAuthType : none
     * addtionalInfo : {"voiceModelId":"1","otpKey":"Y2GGCGHBMWH67Q45","faceModelId":"1"}
     */

    private String epsessionId;
    private boolean authConsumption;
    private String jwt;
    private String optkey;
    private boolean lastauthResult;
    private String authList;
    private String authedList;
    private String nextAuthType;
    private AddtionalInfoBean addtionalInfo;
    private String devBindExpectAuthType;

    public String getEpsessionId() {
        return epsessionId;
    }

    public void setEpsessionId(String epsessionId) {
        this.epsessionId = epsessionId;
    }

    public boolean isAuthConsumption() {
        return authConsumption;
    }

    public void setAuthConsumption(boolean authConsumption) {
        this.authConsumption = authConsumption;
    }

    public String getDevBindExpectAuthType() {
        return devBindExpectAuthType;
    }

    public void setDevBindExpectAuthType(String devBindExpectAuthType) {
        this.devBindExpectAuthType = devBindExpectAuthType;
    }

    public String getJwt() {
        return jwt;
    }

    public void setJwt(String jwt) {
        this.jwt = jwt;
    }

    public String getOptkey() {
        return optkey;
    }

    public void setOptkey(String optkey) {
        this.optkey = optkey;
    }

    public boolean isLastauthResult() {
        return lastauthResult;
    }

    public void setLastauthResult(boolean lastauthResult) {
        this.lastauthResult = lastauthResult;
    }

    public String getAuthList() {
        return authList;
    }

    public void setAuthList(String authList) {
        this.authList = authList;
    }

    public String getAuthedList() {
        return authedList;
    }

    public void setAuthedList(String authedList) {
        this.authedList = authedList;
    }

    public String getNextAuthType() {
        return nextAuthType;
    }

    public void setNextAuthType(String nextAuthType) {
        this.nextAuthType = nextAuthType;
    }

    public AddtionalInfoBean getAddtionalInfo() {
        return addtionalInfo;
    }

    public void setAddtionalInfo(AddtionalInfoBean addtionalInfo) {
        this.addtionalInfo = addtionalInfo;
    }

    public static class AddtionalInfoBean {
        /**
         * voiceModelId : 1
         * otpKey : Y2GGCGHBMWH67Q45
         * faceModelId : 1
         */

        private String voiceModelId;
        private String otpKey;
        private String faceModelId;
        private String mobileNum;

        public String getMobileNum() {
            return mobileNum;
        }

        public void setMobileNum(String mobileNum) {
            this.mobileNum = mobileNum;
        }

        public String getVoiceModelId() {
            return voiceModelId;
        }

        public void setVoiceModelId(String voiceModelId) {
            this.voiceModelId = voiceModelId;
        }

        public String getOtpKey() {
            return otpKey;
        }

        public void setOtpKey(String otpKey) {
            this.otpKey = otpKey;
        }

        public String getFaceModelId() {
            return faceModelId;
        }

        public void setFaceModelId(String faceModelId) {
            this.faceModelId = faceModelId;
        }

        @Override
        public String toString() {
            return "AddtionalInfoBean{" +
                    "voiceModelId='" + voiceModelId + '\'' +
                    ", otpKey='" + otpKey + '\'' +
                    ", faceModelId='" + faceModelId + '\'' +
                    '}';
        }
    }
}
